@@ -19,7 +19,7 @@ class ConfigManager:
             if not os.path.exists(os.path.dirname(self.path)):
                 try:
                     os.makedirs(os.path.dirname(self.path))
-                except OSError as exc: # Guard against race condition
+                except OSError as exc:  # Guard against race condition
                     if exc.errno != errno.EEXIST:
                         raise
             self.__create_default__()
@@ -35,13 +35,11 @@ class ConfigManager:
         logger.add(sys.stderr, level="ERROR")
         logger.add(sys.stdout, level=self.logger_level)
         logger.debug(f"Data path {self.data_path}")
-        self.config["data_path"] = f'{self.config["data_path"]}'
         logger.debug(f"Logger level is {self.logger_level}")
 
     def __write_config__(self):
         with open(Path(self.path), "w") as outfile:
             self.__preset__()
-            self.config["data_path"] = f'{self.config["data_path"]}'
             json.dump(self.config, outfile)
 
     def __create_default__(self) -> dict:
@@ -55,12 +53,11 @@ class ConfigManager:
     @data_path.setter
     def data_path(self, var):
         self.config["data_path"] = var
+        self.__write_config__()
 
     @data_path.getter
     def data_path(self):
-        if self.config.get("data_path", None) is None:
-            self.config["data_path"] = Path.home() / ".servergrimoire/data"
-        return self.config["data_path"]
+        return self.config.get("data_path", Path.home() / ".servergrimoire/data")
 
     @property
     def logger_level(self):
@@ -72,6 +69,19 @@ class ConfigManager:
 
     @logger_level.getter
     def logger_level(self):
-        if self.config.get("logger_level", None) is None:
-            self.config["logger_level"] = "ERROR"
-        return self.config["logger_level"]
+        return self.config.get("logger_level", "ERROR")
+
+    @property
+    def folder_script(self):
+        return self.config["folder_script"]
+
+    @folder_script.setter
+    def folder_script(self, var):
+        self.config["folder_script"] = var
+        self.__write_config__()
+
+    @folder_script.getter
+    def folder_script(self):
+        return self.config.get(
+            "folder_script", Path.home() / ".servergrimoire/script/"
+        )
